%global provider        github
%global provider_tld    com
%global project         ciscorn
%global repo            ldoce5viewer
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit 8004fb9a276c610fb807feaa4a38932e4df190f2
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           ldoce5viewer
Version:        2016.02.06

Release:        1%{?dist}
Summary:        Viewer Application for the Longman Dictionary (LDOCE 5)
License:        GPLv3+
URL:            https://hakidame.net/ldoce5viewer/
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz
Patch0:         %{name}-icongen.patch
BuildArch:      noarch

BuildRequires:  desktop-file-utils
BuildRequires:  gstreamer-python-devel
BuildRequires:  gstreamer-plugins-good
BuildRequires:  gstreamer-plugins-ugly
BuildRequires:  python2-devel
BuildRequires:  python-whoosh
BuildRequires:  python-lxml
BuildRequires:  PyQt4-devel
# To regenerate icons
BuildRequires:  ImageMagick
BuildRequires:  inkscape
BuildRequires:  python-pillow

Requires:       gstreamer-python
Requires:       gstreamer-plugins-good
Requires:       gstreamer-plugins-ugly
Requires:       hicolor-icon-theme
Requires:       python-whoosh
Requires:       python-lxml
Requires:       PyQt4


%description
The %{name} is an alternative dictionary viewer for the
Longman Dictionary of Contemporary English 5th Edition (LDOCE 5).

Features:
    - Comprehensive instant search.
    - Pleasant to use.
    - Clean and readable.
    - Full sound playback.
    - Access virtually all of the LDOCE content.
    - Powerful advanced search.
    - Search in definitions and example sentences.
    - Clipboard monitoring.

Note: Before you can use the app, you have to install
      the original LDOCE 5 software from the DVD-ROM.


%prep
%setup -q -n %{name}-%{commit}
%patch0 -p1

# Update the software version.
sed -i "s#\(__version__.*\ =\ \).*#\1'%{version}'#" %{name}/__init__.py

# Shebang removal
for i in %{name}/__init__.py %{name}/utils/compat.py %{name}.desktop; do
 sed '1{\@^#!/usr/bin/env@d}' $i > $i.tmp &&
 touch -r $i $i.tmp &&
 mv $i.tmp $i
done

# Zero length files removal
find . -size 0 -delete

# Fix python image library import
sed -i "s#\(import Image.*\)#from PIL \1#" %{name}/qtgui/resources/icons/icongen.py

# Be sure all necessary files will be regenerated.
make clean
make -C %{name}/qtgui/resources/icons clean

# Correct EOL (preserve timestamps).
for i in COPYING.txt LICENSE.txt; do
    sed 's#\r##g' $i > $i.tmp && \
    touch -r $i $i.tmp && \
    mv $i.tmp $i
done

# Create simple installation instruction.
cat  > INSTALL.txt <<EOF
1. Copy the 'ldoce5.data' directory from the LDOCE5 DVD-ROM [1]
   to an arbitrary location.

2. Start the %{name}

3. The application will ask you the location where you put 'ldoce5.data'.

More information can be obtained from [2].

[1] http://www.longmandictionariesonline.com/
[2] https://hakidame.net/ldoce5viewer/manual/
EOF


%build
make -C %{name}/qtgui/resources/icons %{?_smp_mflags}
make PYTHON=%{__python2} %{?_smp_mflags} build


%install
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}
desktop-file-install \
    --delete-original \
    --dir=%{buildroot}%{_datadir}/applications \
    %{name}.desktop
install -p -m 0644 -D %{name}/qtgui/resources/%{name}.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%license COPYING.txt LICENSE.txt
%doc INSTALL.txt README.md
%{_bindir}/%{name}
%{python2_sitelib}/*
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%exclude %{python2_sitelib}/%{name}/qtgui/ui/Makefile
%exclude %{python2_sitelib}/%{name}/qtgui/resources/Makefile
%exclude %{python2_sitelib}/%{name}/qtgui/resources/icons/Makefile
%exclude %{python2_sitelib}/%{name}/qtgui/resources/icons/icongen.*


%changelog
* Thu Aug 18 2016 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 2016.02.06-1
- Update to the latest available version.

* Fri May 23 2014 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 2014.02.24-1
- Initial RPM release.
